==> haskell-network-protocol-xmpp-0.4.8-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-network-protocol-xmpp.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: network-protocol-xmpp
version: 0.4.8
id: network-protocol-xmpp-0.4.8-88c2SE3zxxcKYH1YGGiCNR
key: network-protocol-xmpp-0.4.8-88c2SE3zxxcKYH1YGGiCNR
license: GPL-3
maintainer: John Millikin <jmillikin@gmail.com>
stability: experimental
homepage: https://john-millikin.com/software/haskell-xmpp/
synopsis: Client library for the XMPP protocol.
category: Network
author: John Millikin <jmillikin@gmail.com>, Stephan Maka <stephan@spaceboyz.net>
exposed: True
exposed-modules:
    Network.Protocol.XMPP
hidden-modules: Network.Protocol.XMPP.Client
                Network.Protocol.XMPP.Client.Authentication
                Network.Protocol.XMPP.Client.Features
                Network.Protocol.XMPP.Component Network.Protocol.XMPP.Connections
                Network.Protocol.XMPP.ErrorT Network.Protocol.XMPP.Handle
                Network.Protocol.XMPP.JID Network.Protocol.XMPP.Monad
                Network.Protocol.XMPP.Stanza Network.Protocol.XMPP.XML
abi: 1bf6e70faf5694498c694dd1ef4ebade
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/network-protocol-xmpp-0.4.8
library-dirs: /usr/lib/ghc-8.0.1/site-local/network-protocol-xmpp-0.4.8
data-dir: /usr/share/arm-linux-ghc-8.0.1/network-protocol-xmpp-0.4.8
hs-libraries: HSnetwork-protocol-xmpp-0.4.8-88c2SE3zxxcKYH1YGGiCNR
depends:
    base-4.9.0.0 bytestring-0.10.8.1
    gnuidn-0.2.2-87MGCSmpdWq84ETK1mQuJZ
    gnutls-0.2-ACZIL4werDsusgxgdWqtc gsasl-0.3.6-AjrdFfRJ0E1AwlenQFhVXe
    libxml-sax-0.7.5-7moVzqQwMZy3DZrt7QZ9hK
    monads-tf-0.1.0.3-HVD88uwypLB1Pu4HQI1mbn
    network-2.6.3.1-G4Up1CPKbp7DeFsnywOnGG
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v transformers-0.5.2.0
    xml-types-0.3.6-3O22X3xL2Ma4wqqMR9zYLM
haddock-interfaces: /usr/share/doc/haskell-network-protocol-xmpp/html/network-protocol-xmpp.haddock
haddock-html: /usr/share/doc/haskell-network-protocol-xmpp/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-protocol-xmpp-0.4.8-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-network-protocol-xmpp.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: network-protocol-xmpp
version: 0.4.8
id: network-protocol-xmpp-0.4.8-BGs57HfyaUeDyk6aEBwzAb
key: network-protocol-xmpp-0.4.8-BGs57HfyaUeDyk6aEBwzAb
license: GPL-3
maintainer: John Millikin <jmillikin@gmail.com>
stability: experimental
homepage: https://john-millikin.com/software/haskell-xmpp/
synopsis: Client library for the XMPP protocol.
category: Network
author: John Millikin <jmillikin@gmail.com>, Stephan Maka <stephan@spaceboyz.net>
exposed: True
exposed-modules:
    Network.Protocol.XMPP
hidden-modules: Network.Protocol.XMPP.Client
                Network.Protocol.XMPP.Client.Authentication
                Network.Protocol.XMPP.Client.Features
                Network.Protocol.XMPP.Component Network.Protocol.XMPP.Connections
                Network.Protocol.XMPP.ErrorT Network.Protocol.XMPP.Handle
                Network.Protocol.XMPP.JID Network.Protocol.XMPP.Monad
                Network.Protocol.XMPP.Stanza Network.Protocol.XMPP.XML
abi: 834c5e562b0d04ec66a2baec42629516
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/network-protocol-xmpp-0.4.8
library-dirs: /usr/lib/ghc-8.0.1/site-local/network-protocol-xmpp-0.4.8
data-dir: /usr/share/arm-linux-ghc-8.0.1/network-protocol-xmpp-0.4.8
hs-libraries: HSnetwork-protocol-xmpp-0.4.8-BGs57HfyaUeDyk6aEBwzAb
depends:
    base-4.9.0.0 bytestring-0.10.8.1
    gnuidn-0.2.2-87MGCSmpdWq84ETK1mQuJZ
    gnutls-0.2-ACZIL4werDsusgxgdWqtc gsasl-0.3.6-AjrdFfRJ0E1AwlenQFhVXe
    libxml-sax-0.7.5-7moVzqQwMZy3DZrt7QZ9hK
    monads-tf-0.1.0.3-HVD88uwypLB1Pu4HQI1mbn
    network-2.6.3.2-GMjPV5zpIjuBSljTanWiH
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v transformers-0.5.2.0
    xml-types-0.3.6-3O22X3xL2Ma4wqqMR9zYLM
haddock-interfaces: /usr/share/doc/haskell-network-protocol-xmpp/html/network-protocol-xmpp.haddock
haddock-html: /usr/share/doc/haskell-network-protocol-xmpp/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
